@@ -10,8 +10,8 @@ import time
 # Related third party imports
 
 # Local application/library specific imports
-from azure_storage_utils.mapping import ContainerMap
-from azure_storage_utils.mapping import MapReporter
+from mapping import ContainerMap
+from mapping import MapReporter
 
 
 class PipelineOperator:
@@ -22,7 +22,7 @@ class PipelineOperator:
     CONTAINTER_NAME = ""
     CONNECTION_STRING_NAME = 'STORAGE_CONNECTION_STRING'
 
-    def __init__(self, conn_str: str, storage_url: str, container_name: str, map_file_name="storage_map_" + datetime.now().strftime('%Y_%m') + ".json"):
+    def __init__(self, conn_str, storage_url, container_name, map_file_name=f"storage_map_{datetime.now().strftime('%Y_%m')}.json"):
         self.logger = logging.getLogger(__name__)
         logging.basicConfig(level=logging.INFO)
         self.OUTPUT_NAME_JSON = map_file_name
@@ -46,7 +46,7 @@ class PipelineOperator:
         with open(self.OUTPUT_NAME_CSV, "w") as file:
             file.write(csv_data)
 
-    def _check_conn_str(self, conn_str: str, storage_url: str) -> str:
+    def _check_conn_str(self, conn_str, storage_url):
 
         for kw in ['BlobEndpoint', 'QueueEndpoint', 'TableEndPoint', 'FileEndPoint', 'SharedAccessSignature', 'sv']:
             if kw not in conn_str:
