@@ -5,15 +5,15 @@ from copy import error
 import os
 import json
 import sys
+from datetime import datetime
+import logging
 
 # Related third party imports
-import logging
 from azure.storage.blob import ContainerClient
 from azure.storage.fileshare import ShareClient
 from azure.core.exceptions import (
     ResourceNotFoundError,
 )
-from datetime import datetime
 
 TEMP_FOLDER = "/tmp"  # https://learn.microsoft.com/en-us/azure/azure-functions/functions-reference-python?tabs=asgi%2Capplication-level#temporary-files
 HOME_DIR = os.getcwd()
@@ -45,7 +45,7 @@ class ContainerMap:
         self.MAP_FILE_NAME = map_file_name
         self.logger.info("### Init complete")
 
-    def _map_level(self, level: dict, levels: list, blob_size: int, path: str) -> dict:
+    def _map_level(self, level, levels, blob_size, path):
         """Translates a blob's flat path into a tree-like representation recursively, adding the blob's metadata to one 'level' of the tree at a time
 
         Args:
@@ -85,7 +85,7 @@ class ContainerMap:
         # self.logger.info(f"### Finished mapping level: [{current_level}]: [{level}]")
         return level
 
-    def _map_root(self, level: dict) -> dict:
+    def _map_root(self, level):
         """Maps the root level of a blob storage container after all sublevels have been mapped into a dictionary
 
         Args:
@@ -102,7 +102,7 @@ class ContainerMap:
             level['__Size__'] += level['__Contents__'][content]['__Size__']
         return level
 
-    def map_container(self) -> dict:
+    def map_container(self):
         """Creates a json tree representation of the blob storage container, removing the old one of the same name first if it exists
 
         Returns:
@@ -121,7 +121,7 @@ class ContainerMap:
         self.logger.info("### Finished mapping root!")
         return container_map
 
-    def write_map_remote(self, map: dict):
+    def write_map_remote(self, map):
         """Creates json file from storage container map and writes it to the container directly. Overwrites existing file
 
         Args:
@@ -132,7 +132,7 @@ class ContainerMap:
         self.delete_map()
         blob_client.upload_blob(data=json_content)
 
-    def write_map_local(self, map: dict):
+    def write_map_local(self, map):
         """Creates a local copy of the storage container map
 
         Args:
@@ -158,7 +158,7 @@ class FileShareMap:
     generator = None
     logger = None
 
-    def __init__(self, conn_string_name: str, file_share_name: str, prefix: str):
+    def __init__(self, conn_string_name, file_share_name, prefix):
         conn_string = os.environ[conn_string_name]
         self.file_share_client = ShareClient.from_connection_string(
             conn_str=conn_string, share_name=file_share_name)
@@ -168,7 +168,7 @@ class FileShareMap:
         self.blob_prefix = prefix
         self.logger.info("### Init complete")
 
-    def _map_directory(self, directory: dict, absolute_paths: list, ) -> dict:
+    def _map_directory(self, directory, absolute_paths, ):
         parent_directory = "/".join(absolute_paths)
         for obj in list(self.file_share_client.list_directories_and_files(parent_directory)):
             # self.logger.info(f"### Examining [{obj.name}] in parent directory [{parent_directory}]")
@@ -196,13 +196,13 @@ class FileShareMap:
             f"### Finished mapping directory: [{parent_directory}] with number of contents [{len(directory['__Contents__'].keys())}]")
         return directory
 
-    def _map_root(self, level: dict) -> dict:
+    def _map_root(self, level):
         for content in level['__Contents__'].keys():
             level['__Count__'] += level['__Contents__'][content]['__Count__']
             level['__Size__'] += level['__Contents__'][content]['__Size__']
         return level
 
-    def map_file_share(self) -> dict:
+    def map_file_share(self):
         self.delete_map()
         today = datetime.now().strftime("%Y_%m")
         file_share_map = {'__Name__': 'root', '__Size__': 0,
@@ -215,7 +215,7 @@ class FileShareMap:
         self.logger.info("### Finished mapping root!")
         return file_share_map
 
-    def write_map(self, map: dict):
+    def write_map(self, map):
         json_file = json.dumps(map, sort_keys=True, indent=2)
         file_client = self.file_share_client.get_file_client(
             self.MAP_FILE_NAME)
@@ -240,7 +240,7 @@ class MapComparator:
     DEPTH = 0
     PREFIX = ""
 
-    def __init__(self, map1: dict, map2: dict, depth=sys.maxsize):
+    def __init__(self, map1, map2, depth=sys.maxsize):
         self.MAP1 = map1
         self.MAP2 = map2
         self.logger = logging.getLogger(__name__)
@@ -248,14 +248,14 @@ class MapComparator:
         self.DEPTH = depth
         self.logger.info("### Init complete")
 
-    def compare_map(self) -> dict:
+    def compare_map(self):
         """Creates a differential map based on two input maps"""
         diff_map = {}
         diff_map = self._compare_map_full(
             depth=self.DEPTH, map1=self.MAP1, map2=self.MAP2)
         return diff_map
 
-    def _compare_map_full(self, depth: int, map1: dict, map2: dict) -> dict:
+    def _compare_map_full(self, depth, map1, map2):
         diff_level = None
         next_depth = depth - 1
         try:
@@ -327,7 +327,7 @@ class MapComparator:
                 f"Failed at depth [{depth}] while comparing:\n{map1}\n\n{map2}\n\n{e}")
         return diff_level
 
-    def _compare_map_volume_subcontent(self, keys: list, storage_map: dict, diff_map: dict, next_depth: int, map1_primary: bool) -> dict:
+    def _compare_map_volume_subcontent(self, keys, storage_map, diff_map, next_depth, map1_primary):
         for subcontent in keys:  # iterate through unique subcontents
             subcontent_map = storage_map['__Contents__'][subcontent]
             new_subcontent_diff = None
@@ -348,7 +348,7 @@ class MapReporter:
     DEPTH = 0
     PREFIX = ""
 
-    def __init__(self, storage_map: dict, depth=sys.maxsize, prefix=""):
+    def __init__(self, storage_map, depth=sys.maxsize, prefix=""):
         self.logger = logging.getLogger(__name__)
         logging.basicConfig(level=logging.INFO)
         self.STORAGE_MAP = storage_map
@@ -367,7 +367,7 @@ class MapReporter:
                 f"Failed to access storage map using prefix: {self.PREFIX} at level {prefix}:", f"\n{self.STORAGE_MAP}",
                 f"\n{e}")
 
-    def _map_branches(self, map_level: dict, depth=0):
+    def _map_branches(self, map_level, depth=0):
         header_string = ""
         info_string = ""
         self.logger.info(f"### Working depth {depth}: {map_level['__Name__']}")
